@@ -37,7 +37,7 @@ CONF = magnum.conf.CONF
 try:
     CONF.import_opt('fatal_exception_format_errors',
                     'oslo_versionedobjects.exception')
-except cfg.NoSuchOptError as e:
+except cfg.NoSuchOptError:
     # Note:work around for magnum run against master branch
     # in devstack gate job, as magnum not branched yet
     # verisonobjects kilo/master different version can
@@ -350,6 +350,12 @@ class FixedNetworkNotFound(ResourceNotFound):
     code = 400
 
 
+class FixedSubnetNotFound(ResourceNotFound):
+    """The code here changed to 400 according to the latest document."""
+    message = _("Unable to find fixed subnet %(subnet)s.")
+    code = 400
+
+
 class ExternalNetworkNotFound(ResourceNotFound):
     """The code here changed to 400 according to the latest document."""
     """"Ensure the network is not private."""
@@ -435,7 +441,47 @@ class MasterNGResizeNotSupported(NotSupported):
     message = _("Resizing a master nodegroup is not supported.")
 
 
+class ZeroNodeCountNotSupported(NotSupported):
+    message = _("Resizing a nodegroup to zero is not supported in the "
+                "provided microversion.")
+
+
+class ClusterUpgradeNotSupported(NotSupported):
+    message = _("Cluster upgrade is not supported in the "
+                "provided microversion.")
+
+
 class NGResizeOutBounds(Invalid):
     message = _("Resizing %(nodegroup)s outside the allowed range: "
-                "min_node_count = %(min_node_count)s, "
-                "max_node_count = %(max_node_count)s")
+                "min_node_count = %(min_nc)s, "
+                "max_node_count = %(max_nc)s")
+
+
+class DeletingDefaultNGNotSupported(NotSupported):
+    message = _("Deleting a default nodegroup is not supported.")
+
+
+class NodeGroupInvalidInput(Conflict):
+    message = _("%(attr)s for %(nodegroup)s is invalid (%(expl)s).")
+
+
+class CreateMasterNodeGroup(NotSupported):
+    message = _("Creating master nodegroups is currently not supported.")
+
+
+class NgOperationInProgress(Invalid):
+    message = _("Nodegroup %(nodegroup)s already has an operation in "
+                "progress.")
+
+
+class InvalidClusterTemplateForUpgrade(Conflict):
+    message = _("Cluster Template is not valid for upgrade: %(reason)s")
+
+
+class ClusterAPIAddressUnavailable(Conflict):
+    message = _("Cluster API address is not available yet")
+
+
+class ObjectError(MagnumException):
+    message = _("Failed to perform action %{action}s on %{obj_name}s with "
+                "uuid %{obj_id}s: %{reason}s")
