@@ -21,10 +21,16 @@ Create Date: 2016-03-28 09:08:07.467102
 revision = 'e647f5931da8'
 down_revision = '049f81f6f584'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 
 def upgrade():
     op.add_column('baymodel', sa.Column('insecure_registry',
-                                        sa.String(length=255), nullable=True))
+                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        nullable=True))
