@@ -62,7 +62,9 @@ FLANNEL_NETWORK_CIDR="$FLANNEL_NETWORK_CIDR"
 PODS_NETWORK_CIDR="$PODS_NETWORK_CIDR"
 KUBE_VERSION="$KUBE_VERSION"
 TRUSTEE_USER_ID="$TRUSTEE_USER_ID"
+TRUSTEE_USERNAME="$TRUSTEE_USERNAME"
 TRUSTEE_PASSWORD="$TRUSTEE_PASSWORD"
+TRUSTEE_DOMAIN_ID="$TRUSTEE_DOMAIN_ID"
 TRUST_ID="$TRUST_ID"
 CLOUD_PROVIDER_ENABLED="$CLOUD_PROVIDER_ENABLED"
 INSECURE_REGISTRY_URL="$INSECURE_REGISTRY_URL"
