@@ -38,15 +38,16 @@ function create_test_data {
     elif [ "${coe}${special}" == 'k8s-ironic' ]; then
         local bm_flavor_id=$(openstack flavor show baremetal -f value -c id)
         die_if_not_set $LINENO bm_flavor_id "Failed to get id of baremetal flavor"
-
+        # NOTE(TheJulia): This issue was fixed in Feb 2018 as part of change
+        # Ifb9a49d4258a559cf2175d902e9424a3f98065c5. Commented out in Oct 2018.
         # NOTE(yuanying): Workaround fix for ironic issue
         # cf. https://bugs.launchpad.net/ironic/+bug/1596421
-        echo "alter table ironic.nodes modify instance_info LONGTEXT;" | mysql -uroot -p${MYSQL_PASSWORD} ironic
+        # echo "alter table ironic.nodes modify instance_info LONGTEXT;" | mysql -uroot -p${MYSQL_PASSWORD} ironic
         # NOTE(yuanying): Ironic instances need to connect to Internet
         openstack subnet set private-subnet --dns-nameserver 8.8.8.8
         local container_format="ami"
     else
-        local image_name="atomic"
+        local image_name="fedora-coreos"
         local container_format="bare"
     fi
 
@@ -67,7 +68,7 @@ function create_test_data {
     local magnum_api_ip=$(iniget /etc/magnum/magnum.conf api host)
     local magnum_api_port=$(iniget /etc/magnum/magnum.conf api port)
     local magnum_url="http://"$magnum_api_ip":"$magnum_api_port"/v1"
-    local keystone_auth_url=$(iniget /etc/magnum/magnum.conf keystone_authtoken auth_uri)
+    local keystone_auth_url=$(iniget /etc/magnum/magnum.conf keystone_authtoken www_authenticate_uri)
 
     # pass the appropriate variables via a config file
     CREDS_FILE=$MAGNUM_DIR/functional_creds.conf
@@ -114,7 +115,7 @@ EOF
 }
 
 function add_flavor {
-    # because of policy.json change in nova, flavor-create is now an admin-only feature
+    # because of policy.yaml change in nova, flavor-create is now an admin-only feature
     # moving this out to only be used by admins
 
     # Get admin credentials
@@ -130,8 +131,8 @@ function add_flavor {
         local flavor_vcpus="2"
     fi
 
-    openstack flavor create m1.magnum --id 100 --ram ${flavor_ram:-1024} --disk ${flavor_disk:-10} --vcpus ${flavor_vcpus:-1}
-    openstack flavor create s1.magnum --id 200 --ram ${flavor_ram:-1024} --disk ${flavor_disk:-10} --vcpus ${flavor_vcpus:-1}
+    openstack flavor create m1.magnum --id 100 --ram ${flavor_ram:-1024} --disk ${flavor_disk:-10} --vcpus ${flavor_vcpus:-4}
+    openstack flavor create s1.magnum --id 200 --ram ${flavor_ram:-1024} --disk ${flavor_disk:-10} --vcpus ${flavor_vcpus:-4}
 }
 
 if ! function_exists echo_summary; then
@@ -180,48 +181,8 @@ create_test_data $coe $special
 
 _magnum_tests=""
 target="${coe}${special}"
-if [[ "api" == "$coe" ]]; then
-    sudo chown -R $USER:stack $BASE/new/tempest
-
-    export TEMPEST_CONFIG=$BASE/new/tempest/etc/tempest.conf
-
-    # Set up tempest config with magnum goodness
-    iniset $TEMPEST_CONFIG magnum image_id $IMAGE_ID
-    iniset $TEMPEST_CONFIG magnum nic_id $NIC_ID
-    iniset $TEMPEST_CONFIG magnum keypair_id default
-    iniset $TEMPEST_CONFIG magnum flavor_id s1.magnum
-    iniset $TEMPEST_CONFIG magnum master_flavor_id m1.magnum
-    iniset $TEMPEST_CONFIG magnum copy_logs True
-
-    # show tempest config with magnum
-    cat $TEMPEST_CONFIG
-    # tempest tox env is looking for /etc/tempest/tempest.conf
-    sudo mkdir -p /etc/tempest
-    sudo cp $TEMPEST_CONFIG /etc/tempest/tempest.conf
-
-    # strigazi: don't run test_create_list_sign_delete_clusters because
-    # it is very unstable in the CI
-    _magnum_tests="magnum_tempest_plugin.tests.api.v1.test_bay"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_baymodel"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster_template"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster_template_admin"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_magnum_service"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster.ClusterTest.test_create_cluster_for_nonexisting_cluster_template"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster.ClusterTest.test_create_cluster_with_node_count_0"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster.ClusterTest.test_create_cluster_with_nonexisting_flavor"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster.ClusterTest.test_create_cluster_with_zero_masters"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster.ClusterTest.test_delete_cluster_for_nonexisting_cluster"
-    _magnum_tests="$_magnum_tests magnum_tempest_plugin.tests.api.v1.test_cluster.ClusterTest.test_update_cluster_for_nonexisting_cluster"
-
-    pushd $BASE/new/magnum-tempest-plugin
-    sudo cp $CREDS_FILE .
-    sudo -E -H -u $USER tox -e functional-"$target" $_magnum_tests -- --concurrency=1
-    EXIT_CODE=$?
-    popd
-else
-    sudo -E -H -u $USER tox -e functional-"$target" $_magnum_tests -- --concurrency=1
-    EXIT_CODE=$?
-fi
+sudo -E -H -u $USER tox -e functional-"$target" $_magnum_tests -- --concurrency=1
+EXIT_CODE=$?
 
 
 # Delete the keypair used in the functional test.
